.. _DPCT1002:

DPCT1002
========

Message
-------

.. _msg-1002-start:

Special case error handling ``if-stmt`` was detected. You may need to rewrite
this code.

.. _msg-1002-end:

Detailed Help
-------------

See :ref:`DPCT1000`.

Suggestions to Fix
------------------

For example, this original CUDA\* code:

.. code-block:: cpp
   :linenos:

   void foo() {
     float *f;
     cudaError_t err = cudaMalloc(&f, 4);
     if (err == cudaErrorMemoryAllocation) {
       std::cerr << "cudaErrorMemoryAllocation" << std::endl;
     }
   }

results in the following migrated SYCL\* code:

.. code-block:: cpp
   :linenos:

   void foo() {
     float *f;
     int err = (f = (float *)sycl::malloc_device(4, dpct::get_default_queue()), 0);
     /*
     DPCT1002:1: Special case error handling if-stmt was detected. You may need to
     rewrite this code.
     */
     if (err == 2) {
       std::cerr << "cudaErrorMemoryAllocation" << std::endl;
     }
   }

which is rewritten to:

.. code-block:: cpp
   :linenos:

   void foo() {
     float *f;
     try {
       f = (float *)sycl::malloc_device(4, dpct::get_default_queue());
     } catch (sycl::exception const &e) {
       std::cerr << e.what() << std::endl;
     }
   }

